@@ -1,11 +1,13 @@
 import sys
 import types
 
-from je_auto_control import check_key_is_press, position, press_mouse, release_mouse, click_mouse, scroll
-from je_auto_control import locate_all_image, locate_and_click, locate_image_center
-from je_auto_control import press_key, release_key, hotkey, type_key, write, record, stop_record
-from je_auto_control import screenshot, size
-from je_auto_control import set_position
+from je_auto_control.wrapper.auto_control_keyboard import check_key_is_press
+from je_auto_control.wrapper.auto_control_mouse import position, press_mouse, release_mouse, click_mouse, scroll
+from je_auto_control.wrapper.auto_control_image import locate_all_image, locate_and_click, locate_image_center
+from je_auto_control.wrapper.auto_control_keyboard import press_key, release_key, hotkey, type_key, write
+from je_auto_control.wrapper.auto_control_record import record, stop_record
+from je_auto_control.wrapper.auto_control_screen import screenshot, size
+from je_auto_control.wrapper.auto_control_mouse import set_position
 from je_auto_control.utils.exception.exception_tag import action_is_null_error, add_command_exception_tag, \
     executor_list_error
 from je_auto_control.utils.exception.exception_tag import cant_execute_action_error
