@@ -1,14 +1,14 @@
 import sys
 from typing import List, Union
 
-from je_auto_control.utils.image import template_detection
 from je_auto_control.utils.exception.exception_tag import cant_find_image
 from je_auto_control.utils.exception.exception_tag import find_image_error_variable
 from je_auto_control.utils.exception.exceptions import ImageNotFoundException
+from je_auto_control.utils.image import template_detection
+from je_auto_control.utils.image.screenshot import pil_screenshot
+from je_auto_control.utils.test_record.record_test_class import record_action_to_list
 from je_auto_control.wrapper.auto_control_mouse import click_mouse
 from je_auto_control.wrapper.auto_control_mouse import set_position
-from je_auto_control.utils.image.screenshot import pil_screenshot
-from je_auto_control.utils.test_record.record_test_class import record_total
 
 
 def locate_all_image(image, detect_threshold: [float, int] = 1,
@@ -26,12 +26,12 @@ def locate_all_image(image, detect_threshold: [float, int] = 1,
         except ImageNotFoundException as error:
             raise ImageNotFoundException(find_image_error_variable + " " + repr(error))
         if image_data_array[0] is True:
-            record_total("locate_all_image", param)
+            record_action_to_list("locate_all_image", param)
             return image_data_array[1]
         else:
             raise ImageNotFoundException(cant_find_image)
     except Exception as error:
-        record_total("locate_all_image", param, repr(error))
+        record_action_to_list("locate_all_image", param, repr(error))
         print(repr(error), file=sys.stderr)
 
 
@@ -52,12 +52,12 @@ def locate_image_center(image, detect_threshold: [float, int] = 1, draw_image: b
             height = image_data_array[1][2] - image_data_array[1][0]
             width = image_data_array[1][3] - image_data_array[1][1]
             center = [int(height / 2), int(width / 2)]
-            record_total("locate_image_center", param)
+            record_action_to_list("locate_image_center", param)
             return [image_data_array[1][0] + center[0], image_data_array[1][1] + center[1]]
         else:
             raise ImageNotFoundException(cant_find_image)
     except Exception as error:
-        record_total("locate_image_center", param, repr(error))
+        record_action_to_list("locate_image_center", param, repr(error))
         print(repr(error), file=sys.stderr)
 
 
@@ -86,12 +86,12 @@ def locate_and_click(
             image_center_y = image_data_array[1][1] + center[1]
             set_position(int(image_center_x), int(image_center_y))
             click_mouse(mouse_keycode)
-            record_total("locate_and_click", param)
+            record_action_to_list("locate_and_click", param)
             return [image_center_x, image_center_y]
         else:
             raise ImageNotFoundException(cant_find_image)
     except Exception as error:
-        record_total("locate_and_click", param, repr(error))
+        record_action_to_list("locate_and_click", param, repr(error))
         print(repr(error), file=sys.stderr)
 
 
@@ -103,8 +103,8 @@ def screenshot(file_path: str = None, region: list = None) -> List[Union[int, in
     """
     param = locals()
     try:
-        record_total("screenshot", param)
+        record_action_to_list("screenshot", param)
         return pil_screenshot(file_path, region)
     except Exception as error:
         print(repr(error), file=sys.stderr)
-        record_total("screenshot", param, repr(error))
+        record_action_to_list("screenshot", param, repr(error))
